@@ -4,8 +4,6 @@ module Main where
 import Test.Framework
 import Hasql.Postgres.Prelude
 
-import {-@ HTF_TESTS @-} Hasql.Postgres.ParserTests
-import {-@ HTF_TESTS @-} Hasql.Postgres.ParserAndRendererTests
 import {-@ HTF_TESTS @-} Hasql.Postgres.TemplateConverterTests
 
 main = 
